@@ -1,7 +1,7 @@
 /*
  * Cantata
  *
- * Copyright (c) 2011-2016 Craig Drummond <craig.p.drummond@gmail.com>
+ * Copyright (c) 2011-2017 Craig Drummond <craig.p.drummond@gmail.com>
  *
  * ----
  *
@@ -32,7 +32,6 @@
 #include "mpd-interface/mpdparseutils.h"
 #include "mpd-interface/mpdconnection.h"
 #include "encoders.h"
-#include "support/localize.h"
 #include "support/messagebox.h"
 #include "filejob.h"
 #include "freespaceinfo.h"
@@ -124,7 +123,7 @@ void ActionDialog::controlInfoLabel(Device *dev)
         codec->setVisible(true);
         Encoders::Encoder encoder=Encoders::getEncoder(opts.transcoderCodec);
         if (Encoders::getEncoder(opts.transcoderCodec).codec.isEmpty()) {
-            codec->setText(i18n("<b>INVALID</b>"));
+            codec->setText(tr("<b>INVALID</b>"));
         } else if (encoder.values.count()>1) {
             int settingIndex=0;
             bool increase=encoder.values.at(0).value<encoder.values.at(1).value;
@@ -138,10 +137,10 @@ void ActionDialog::controlInfoLabel(Device *dev)
                 index++;
             }
             codec->setText(QString("%1 (%2)").arg(encoder.name).arg(encoder.values.at(settingIndex).descr)+
-                           (sourceIsAudioCd && opts.transcoderWhenDifferent ? QLatin1String("")+i18n("<i>(When different)</i>") : QString()));
+                           (sourceIsAudioCd && opts.transcoderWhenDifferent ? QLatin1String("")+tr("<i>(When different)</i>") : QString()));
         } else {
             codec->setText(encoder.name+
-                           (sourceIsAudioCd && opts.transcoderWhenDifferent ? QLatin1String("")+i18n("<i>(When different)</i>") : QString()));
+                           (sourceIsAudioCd && opts.transcoderWhenDifferent ? QLatin1String("")+tr("<i>(When different)</i>") : QString()));
         }
     }
 }
@@ -170,7 +169,7 @@ void ActionDialog::updateSongCountLabel()
         albums.insert(s.albumArtist()+"--"+s.album);
     }
 
-    songCount->setText(i18n("Artists:%1, Albums:%2, Songs:%3", artists.count(), albums.count(), songsToAction.count()));
+    songCount->setText(tr("Artists:%1, Albums:%2, Songs:%3").arg(artists.count()).arg(albums.count()).arg(songsToAction.count()));
 }
 
 void ActionDialog::controlInfoLabel()
@@ -211,9 +210,6 @@ void ActionDialog::calcFileSize()
         if (!haveVariousArtists && s.isVariousArtists()) {
             haveVariousArtists=true;
         }
-        #ifdef ACTION_DIALOG_SHOW_TIME_REMAINING
-        totalTime+=s.time;
-        #endif
     }
     fileSizeProgress->setValue(fileSizeProgress->value()+toCalc);
     if (!songsToCalcSize.isEmpty()) {
@@ -241,7 +237,7 @@ void ActionDialog::calcFileSize()
             FreeSpaceInfo inf=FreeSpaceInfo(MPDConnection::self()->getDetails().dir);
             spaceAvailable=inf.size()-inf.used();
             usedCapacity=(inf.used()*1.0)/(inf.size()*1.0);
-            capacityString=i18n("%1 free", Utils::formatByteSize(inf.size()-inf.used()));
+            capacityString=tr("%1 free").arg(Utils::formatByteSize(inf.size()-inf.used()));
         }
 
         bool enoughSpace=spaceAvailable>spaceRequired;
@@ -254,11 +250,11 @@ void ActionDialog::calcFileSize()
             QString mpdCfgName=MPDConnectionDetails::configGroupName(MPDConnection::self()->getDetails().name);
             overwrite->setChecked(Settings::self()->overwriteSongs());
             sourceLabel->setText(QLatin1String("<b>")+(sourceUdi.isEmpty()
-                                    ? i18n("Local Music Library")
+                                    ? tr("Local Music Library")
                                     : sourceIsAudioCd
-                                        ? i18n("Audio CD")
+                                        ? tr("Audio CD")
                                         : dev->data())+QLatin1String("</b>"));
-            destinationLabel->setText(QLatin1String("<b>")+(destUdi.isEmpty() ? i18n("Local Music Library") : dev->data())+QLatin1String("</b>"));
+            destinationLabel->setText(QLatin1String("<b>")+(destUdi.isEmpty() ? tr("Local Music Library") : dev->data())+QLatin1String("</b>"));
             namingOptions.load(mpdCfgName, true);
 
             capacity->update(capacityString, (usedCapacity*100)+0.5);
@@ -280,20 +276,20 @@ void ActionDialog::calcFileSize()
             } else {
                 setPage(PAGE_INSUFFICIENT_SIZE);
                 sizeInfoIcon->setPixmap(*(skipIcon->pixmap()));
-                sizeInfoText->setText(i18n("There is insufficient space left on the destination device.\n\n"
-                                           "The selected songs consume %1, but there is only %2 left.\n"
-                                           "The songs will need to be transcoded to a smaller filesize in order to be successfully copied.",
-                                           Utils::formatByteSize(spaceRequired),
-                                           Utils::formatByteSize(spaceAvailable)));
+                sizeInfoText->setText(tr("There is insufficient space left on the destination device.\n\n"
+                                          "The selected songs consume %1, but there is only %2 left.\n"
+                                          "The songs will need to be transcoded to a smaller filesize in order to be successfully copied.")
+                                          .arg(Utils::formatByteSize(spaceRequired))
+                                          .arg(Utils::formatByteSize(spaceAvailable)));
             }
         } else {
             setPage(PAGE_INSUFFICIENT_SIZE);
             setButtons(Cancel);
             sizeInfoIcon->setPixmap(*(errorIcon->pixmap()));
-            sizeInfoText->setText(i18n("There is insufficient space left on the destination.\n\n"
-                                       "The selected songs consume %1, but there is only %2 left.",
-                                       Utils::formatByteSize(spaceRequired),
-                                       Utils::formatByteSize(spaceAvailable)));
+            sizeInfoText->setText(tr("There is insufficient space left on the destination.\n\n"
+                                      "The selected songs consume %1, but there is only %2 left.")
+                                      .arg(Utils::formatByteSize(spaceRequired))
+                                      .arg(Utils::formatByteSize(spaceAvailable)));
         }
     }
 }
@@ -304,7 +300,7 @@ void ActionDialog::sync(const QString &devId, const QList<Song> &libSongs, const
     bool toLib=libSongs.isEmpty();
     if (toLib || devSongs.isEmpty()) {
         copy(toLib ? devId : QString(), toLib ? QString() : devId, toLib ? devSongs : libSongs);
-        setCaption(toLib ? i18n("Copy Songs To Library") : i18n("Copy Songs To Device"));
+        setCaption(toLib ? tr("Copy Songs To Library") : tr("Copy Songs To Device"));
         return;
     }
 
@@ -324,7 +320,7 @@ void ActionDialog::sync(const QString &devId, const QList<Song> &libSongs, const
     fileSizeProgress->setMaximum(songsToAction.size());
     songsToCalcSize=songsToAction;
     syncSongs=devSongs;
-    setCaption(toLib ? i18n("Copy Songs To Library") : i18n("Copy Songs To Device"));
+    setCaption(toLib ? tr("Copy Songs To Library") : tr("Copy Songs To Device"));
     setPage(PAGE_SIZE_CALC);
     show();
     calcFileSize();
@@ -377,9 +373,6 @@ void ActionDialog::remove(const QString &udi, const QList<Song> &songs)
         dirsToClean.insert(baseDir+Utils::getDir(s.file));
     }
     show();
-    #ifdef ACTION_DIALOG_SHOW_TIME_REMAINING
-    timer.start();
-    #endif
     doNext();
 }
 
@@ -391,7 +384,7 @@ void ActionDialog::init(const QString &srcUdi, const QString &dstUdi, const QLis
     sourceIsAudioCd=false;
     songsToAction=songs;
     mode=m;
-    setCaption(Copy==mode || Sync==mode ? i18n("Copy Songs") : i18n("Delete Songs"));
+    setCaption(Copy==mode || Sync==mode ? tr("Copy Songs") : tr("Delete Songs"));
     qSort(songsToAction);
     progressLabel->setText(QString());
     progressBar->setValue(0);
@@ -401,10 +394,6 @@ void ActionDialog::init(const QString &srcUdi, const QString &dstUdi, const QLis
     paused=false;
     actionedSongs.clear();
     skippedSongs.clear();
-    #ifdef ACTION_DIALOG_SHOW_TIME_REMAINING
-    actionedTime=0;
-    timeTaken=0;
-    #endif
     currentPercent=0;
     currentDev=0;
     count=0;
@@ -432,21 +421,18 @@ void ActionDialog::slotButtonClicked(int button)
         case Ok:
             if (haveVariousArtists &&
                 ((configureDestLabel->isVisible() && sourceUdi.isEmpty() && // Only warn if copying FROM library
-                  MessageBox::No==MessageBox::warningYesNo(this, i18n("You have not configured the destination device.\n\n"
-                                                                      "Continue with the default settings?"), i18n("Not Configured"),
-                                                           GuiItem(i18n("Use Defaults")), StdGuiItem::cancel())) ||
+                  MessageBox::No==MessageBox::warningYesNo(this, tr("You have not configured the destination device.\n\n"
+                                                                      "Continue with the default settings?"), tr("Not Configured"),
+                                                           GuiItem(tr("Use Defaults")), StdGuiItem::cancel())) ||
                  (configureSourceLabel->isVisible() && !sourceUdi.isEmpty() && // Only warn if copying TO library
-                  MessageBox::No==MessageBox::warningYesNo(this, i18n("You have not configured the source device.\n\n"
-                                                                      "Continue with the default settings?"), i18n("Not Configured"),
-                                                           GuiItem(i18n("Use Defaults")), StdGuiItem::cancel())) ) ) {
+                  MessageBox::No==MessageBox::warningYesNo(this, tr("You have not configured the source device.\n\n"
+                                                                      "Continue with the default settings?"), tr("Not Configured"),
+                                                           GuiItem(tr("Use Defaults")), StdGuiItem::cancel())) ) ) {
                 return;
             }
             Settings::self()->saveOverwriteSongs(overwrite->isChecked());
             setPage(PAGE_PROGRESS);
 //            hideSongs();
-            #ifdef ACTION_DIALOG_SHOW_TIME_REMAINING
-            timer.start();
-            #endif
             doNext();
             break;
         case Cancel:
@@ -461,17 +447,10 @@ void ActionDialog::slotButtonClicked(int button)
         }
         break;
     case PAGE_SKIP:
-        #ifdef ACTION_DIALOG_SHOW_TIME_REMAINING
-        timeTaken+=timer.elapsed();
-        #endif
         setPage(PAGE_PROGRESS);
         switch(button) {
         case User1:
             skippedSongs.append(currentSong);
-            #ifdef ACTION_DIALOG_SHOW_TIME_REMAINING
-            totalTime-=currentSong.time;
-            timer.restart();
-            #endif
             incProgress();
             doNext();
             break;
@@ -498,7 +477,7 @@ void ActionDialog::slotButtonClicked(int button)
         break;
     case PAGE_PROGRESS:
         paused=true;
-        if (MessageBox::Yes==MessageBox::questionYesNo(this, i18n("Are you sure you wish to stop?"), i18n("Stop"),
+        if (MessageBox::Yes==MessageBox::questionYesNo(this, tr("Are you sure you wish to stop?"), tr("Stop"),
                                                        StdGuiItem::stop(), StdGuiItem::cont())) {
             Device *dev=0;
             if(Copy==mode || Sync==mode) {
@@ -543,13 +522,13 @@ Device * ActionDialog::getDevice(const QString &udi, bool logErrors)
 
     QString error;
     if (!dev) {
-        error=i18n("Device has been removed!");
+        error=tr("Device has been removed!");
     } else if (!dev->isConnected()) {
-        error=i18n("Device is not connected!");
+        error=tr("Device is not connected!");
     } else if (!dev->isIdle()) {
-        error=i18n("Device is busy?");
+        error=tr("Device is busy?");
     } else if (currentDev && dev!=currentDev) {
-        error=i18n("Device has been changed?");
+        error=tr("Device has been changed?");
     }
 
     if (error.isEmpty()) {
@@ -573,7 +552,7 @@ void ActionDialog::doNext()
         syncSongs.clear();
         sourceUdi=destUdi;
         destUdi=QString();
-        setCaption(i18n("Copy Songs To Library"));
+        setCaption(tr("Copy Songs To Library"));
     }
 
     if (songsToAction.count()) {
@@ -620,11 +599,11 @@ void ActionDialog::doNext()
                 }
             }
         }
-        progressLabel->setText(formatSong(currentSong, false, true));
+        progressLabel->setText(formatSong(currentSong, false));
     } else if (Remove==mode && dirsToClean.count()) {
         Device *dev=sourceUdi.isEmpty() ? 0 : DevicesModel::self()->device(sourceUdi);
         if (sourceUdi.isEmpty() || dev) {
-            progressLabel->setText(i18n("Clearing unused folders"));
+            progressLabel->setText(tr("Clearing unused folders"));
             if (dev) {
                 dev->cleanDirs(dirsToClean);
             } else {
@@ -639,8 +618,8 @@ void ActionDialog::doNext()
             #ifdef ENABLE_REPLAYGAIN_SUPPORT
             if (Copy==mode && !albumsWithoutRgTags.isEmpty() && sourceIsAudioCd) {
                 QWidget *pw=parentWidget();
-                if (MessageBox::Yes==MessageBox::questionYesNo(pw, i18n("Calculate ReplayGain for ripped tracks?"), i18n("ReplayGain"),
-                                                               GuiItem(i18n("Calculate")), StdGuiItem::no())) {
+                if (MessageBox::Yes==MessageBox::questionYesNo(pw, tr("Calculate ReplayGain for ripped tracks?"), tr("ReplayGain"),
+                                                               GuiItem(tr("Calculate")), StdGuiItem::no())) {
                     RgDialog *dlg=new RgDialog(pw);
                     QList<Song> songs;
                     DeviceOptions opts;
@@ -668,9 +647,6 @@ void ActionDialog::actionStatus(int status, bool copiedCover)
     bool wasSkip=false;
     if (Device::Ok!=status && Device::NotConnected!=status && autoSkip) {
         skippedSongs.append(currentSong);
-        #ifdef ACTION_DIALOG_SHOW_TIME_REMAINING
-        totalTime-=currentSong.time;
-        #endif
         wasSkip=true;
         status=Device::Ok;
     }
@@ -680,9 +656,6 @@ void ActionDialog::actionStatus(int status, bool copiedCover)
         if (Device::Ok==origStatus) {
             if (!wasSkip) {
                 actionedSongs.append(currentSong);
-                #ifdef ACTION_DIALOG_SHOW_TIME_REMAINING
-                actionedTime+=currentSong.time;
-                #endif
                 #ifdef ENABLE_REPLAYGAIN_SUPPORT
                 if (Copy==mode && sourceIsAudioCd && !albumsWithoutRgTags.contains(currentSong.album) && Tags::readReplaygain(destFile).isEmpty()) {
                     albumsWithoutRgTags.insert(currentSong.album);
@@ -699,52 +672,52 @@ void ActionDialog::actionStatus(int status, bool copiedCover)
         }
         break;
     case Device::FileExists:
-        setPage(PAGE_SKIP, formatSong(currentSong, true), i18n("The destination filename already exists!"));
+        setPage(PAGE_SKIP, formatSong(currentSong, true), tr("The destination filename already exists!"));
         break;
     case Device::SongExists:
-        setPage(PAGE_SKIP, formatSong(currentSong), i18n("Song already exists!"));
+        setPage(PAGE_SKIP, formatSong(currentSong), tr("Song already exists!"));
         break;
     case Device::SongDoesNotExist:
-        setPage(PAGE_SKIP, formatSong(currentSong), i18n("Song does not exist!"));
+        setPage(PAGE_SKIP, formatSong(currentSong), tr("Song does not exist!"));
         break;
     case Device::DirCreationFaild:
-        setPage(PAGE_SKIP, formatSong(currentSong, true), i18n("Failed to create destination folder!<br/>Please check you have sufficient permissions."));
+        setPage(PAGE_SKIP, formatSong(currentSong, true), tr("Failed to create destination folder!<br/>Please check you have sufficient permissions."));
         break;
     case Device::SourceFileDoesNotExist:
-        setPage(PAGE_SKIP, formatSong(currentSong, true), i18n("Source file no longer exists?"));
+        setPage(PAGE_SKIP, formatSong(currentSong, true), tr("Source file no longer exists?"));
         break;
     case Device::Failed:
-        setPage(PAGE_SKIP, formatSong(currentSong), Copy==mode || Sync==mode ? i18n("Failed to copy.") : i18n("Failed to delete."));
+        setPage(PAGE_SKIP, formatSong(currentSong), Copy==mode || Sync==mode ? tr("Failed to copy.") : tr("Failed to delete."));
         break;
     case Device::NotConnected:
-        setPage(PAGE_ERROR, formatSong(currentSong), i18n("Not connected to device."));
+        setPage(PAGE_ERROR, formatSong(currentSong), tr("Not connected to device."));
         break;
     case Device::CodecNotAvailable:
-        setPage(PAGE_ERROR, formatSong(currentSong), i18n("Selected codec is not available."));
+        setPage(PAGE_ERROR, formatSong(currentSong), tr("Selected codec is not available."));
         break;
     case Device::TranscodeFailed:
-        setPage(PAGE_SKIP, formatSong(currentSong), i18n("Transcoding failed."));
+        setPage(PAGE_SKIP, formatSong(currentSong), tr("Transcoding failed."));
         break;
     case Device::FailedToCreateTempFile:
-        setPage(PAGE_ERROR, formatSong(currentSong), i18n("Failed to create temporary file.<br/>(Required for transcoding to MTP devices.)"));
+        setPage(PAGE_ERROR, formatSong(currentSong), tr("Failed to create temporary file.<br/>(Required for transcoding to MTP devices.)"));
         break;
     case Device::ReadFailed:
-        setPage(PAGE_SKIP, formatSong(currentSong), i18n("Failed to read source file."));
+        setPage(PAGE_SKIP, formatSong(currentSong), tr("Failed to read source file."));
         break;
     case Device::WriteFailed:
-        setPage(PAGE_SKIP, formatSong(currentSong), i18n("Failed to write to destination file."));
+        setPage(PAGE_SKIP, formatSong(currentSong), tr("Failed to write to destination file."));
         break;
     case Device::NoSpace:
-        setPage(PAGE_SKIP, formatSong(currentSong), i18n("No space left on device."));
+        setPage(PAGE_SKIP, formatSong(currentSong), tr("No space left on device."));
         break;
     case Device::FailedToUpdateTags:
-        setPage(PAGE_SKIP, formatSong(currentSong), i18n("Failed to update metadata."));
+        setPage(PAGE_SKIP, formatSong(currentSong), tr("Failed to update metadata."));
         break;
     case Device::DownloadFailed:
-        setPage(PAGE_SKIP, formatSong(currentSong), i18n("Failed to download track."));
+        setPage(PAGE_SKIP, formatSong(currentSong), tr("Failed to download track."));
         break;
     case Device::FailedToLockDevice:
-        setPage(PAGE_ERROR, formatSong(currentSong), i18n("Failed to lock device."));
+        setPage(PAGE_ERROR, formatSong(currentSong), tr("Failed to lock device."));
         break;
     case Device::Cancelled:
         break;
@@ -773,7 +746,7 @@ void ActionDialog::configure(const QString &udi)
         if (!mpdConfigured) {
             connect(dlg, SIGNAL(cancelled()), SLOT(saveProperties()));
         }
-        dlg->setCaption(i18n("Local Music Library Properties"));
+        dlg->setCaption(tr("Local Music Library Properties"));
         dlg->show(MPDConnection::self()->getDetails().dir, namingOptions, DevicePropertiesWidget::Prop_Basic|DevicePropertiesWidget::Prop_FileName|(sourceIsAudioCd ? DevicePropertiesWidget::Prop_Encoder : 0));
         connect(dlg, SIGNAL(destroyed()), SLOT(controlInfoLabel()));
     } else {
@@ -825,59 +798,42 @@ void ActionDialog::setPage(int page, const StringPairList &msg, const QString &h
         break;
     case PAGE_SKIP:
         actionLabel->stopAnimation();
-        skipText->setText(msg, QLatin1String("<b>")+i18n("Error")+QLatin1String("</b><br/>")+header+
+        skipText->setText(msg, QLatin1String("<b>")+tr("Error")+QLatin1String("</b><br/>")+header+
                           (header.isEmpty() ? QString() : QLatin1String("<br/><br/>")));
         if (songsToAction.count()) {
             setButtons(Cancel|User1|User2|User3);
-            setButtonText(User1, i18n("Skip"));
-            setButtonText(User2, i18n("Auto Skip"));
+            setButtonText(User1, tr("Skip"));
+            setButtonText(User2, tr("Auto Skip"));
         } else {
             setButtons(Cancel|User3);
         }
-        setButtonText(User3, i18n("Retry"));
+        setButtonText(User3, tr("Retry"));
         break;
     case PAGE_ERROR:
         actionLabel->stopAnimation();
         stack->setCurrentIndex(PAGE_ERROR);
-        errorText->setText(msg, QLatin1String("<b>")+i18n("Error")+QLatin1String("</b><br/>")+header+
+        errorText->setText(msg, QLatin1String("<b>")+tr("Error")+QLatin1String("</b><br/>")+header+
                            (header.isEmpty() ? QString() : QLatin1String("<br/><br/>")));
         setButtons(Cancel);
         break;
     }
 }
 
-ActionDialog::StringPairList ActionDialog::formatSong(const Song &s, bool showFiles, bool showTime)
+ActionDialog::StringPairList ActionDialog::formatSong(const Song &s, bool showFiles)
 {
     StringPairList str;
-    str.append(StringPair(i18n("Artist:"), s.albumArtist()));
-    str.append(StringPair(i18n("Album:"), s.album));
-    str.append(StringPair(i18n("Track:"), s.trackAndTitleStr()));
+    str.append(StringPair(tr("Artist:"), s.albumArtist()));
+    str.append(StringPair(tr("Album:"), s.album));
+    str.append(StringPair(tr("Track:"), s.trackAndTitleStr()));
 
     if (showFiles) {
         if (Copy==mode || Sync==mode) {
-            str.append(StringPair(i18n("Source file:"), DevicesModel::fixDevicePath(s.filePath())));
-            str.append(StringPair(i18n("Destination file:"), DevicesModel::fixDevicePath(destFile)));
+            str.append(StringPair(tr("Source file:"), DevicesModel::fixDevicePath(s.filePath())));
+            str.append(StringPair(tr("Destination file:"), DevicesModel::fixDevicePath(destFile)));
         } else {
-            str.append(StringPair(i18n("File:"), DevicesModel::fixDevicePath(s.filePath())));
+            str.append(StringPair(tr("File:"), DevicesModel::fixDevicePath(s.filePath())));
         }
     }
-
-    #ifdef ACTION_DIALOG_SHOW_TIME_REMAINING
-    if (showTime) {
-        QString estimate=i18n("Calculating...");
-        double taken=timeTaken+timer.elapsed();
-        if (taken>5.0) {
-            double pc=(progressBar->value()*1.0)/(progressBar->maximum()*1.0);
-            double percent=Copy==mode ? (actionedTime+(currentPercent*0.01*currentSong.time))/totalTime : pc;
-            percent-=percent*((1.0-percent)*0.15);
-            quint64 timeRemaining=((taken/percent)-taken)/1000.0;
-            estimate=i18nc("time (Estimated)", "%1 (Estimated)", Song::formattedTime(timeRemaining>0 ? timeRemaining : 0));
-        }
-        str.append(StringPair(i18n("Time remaining:"), estimate);
-    }
-    #else
-    Q_UNUSED(showTime)
-    #endif
     
     return str;
 }
@@ -893,7 +849,7 @@ bool ActionDialog::refreshLibrary()
             if (dev) {
                 connect(dev, SIGNAL(cacheSaved()), this, SLOT(cacheSaved()));
                 dev->saveCache();
-                progressLabel->setText(i18n("Saving cache"));
+                progressLabel->setText(tr("Saving cache"));
                 setButtons(Close);
                 return true;
             }
@@ -909,7 +865,7 @@ bool ActionDialog::refreshLibrary()
             if (dev) {
                 connect(dev, SIGNAL(cacheSaved()), this, SLOT(cacheSaved()));
                 dev->saveCache();
-                progressLabel->setText(i18n("Saving cache"));
+                progressLabel->setText(tr("Saving cache"));
                 setButtons(Close);
                 return true;
             }
@@ -963,7 +919,7 @@ void ActionDialog::jobPercent(int percent)
         updateUnity(false);
         currentPercent=percent;
         if (PAGE_PROGRESS==stack->currentIndex()) {
-            progressLabel->setText(formatSong(currentSong, false, true));
+            progressLabel->setText(formatSong(currentSong, false));
         }
     }
 }
