@@ -221,10 +221,14 @@ void DevicePropertiesWidget::update(const QString &path, const DeviceOptions &op
             transcoderValue->setVisible(false);
             transcoderWhenDifferent->setVisible(false);
             transcoderWhenDifferent->setChecked(opts.transcoderWhenDifferent);
+            transcoderWhenSourceIsLosssless->setVisible(false);
+            transcoderWhenSourceIsLosssless->setChecked(opts.transcoderWhenSourceIsLosssless);
             connect(transcoderWhenDifferent, SIGNAL(stateChanged(int)), this, SLOT(checkSaveable()));
+            connect(transcoderWhenSourceIsLosssless, SIGNAL(stateChanged(int)), this, SLOT(checkSaveable()));
         } else {
             transcoderFrame->setTitle(tr("Encoder"));
             REMOVE(transcoderWhenDifferent);
+            REMOVE(transcoderWhenSourceIsLosssless);
         }
 
         QList<Encoders::Encoder> encs=Encoders::getAvailable();
@@ -307,12 +311,18 @@ void DevicePropertiesWidget::transcoderChanged()
         if (transcoderWhenDifferent) {
             transcoderWhenDifferent->setVisible(false);
         }
+        if (transcoderWhenSourceIsLosssless) {
+            transcoderWhenSourceIsLosssless->setVisible(false);
+        }
     } else {
         Encoders::Encoder enc=Encoders::getEncoder(codec);
         transcoderName->setToolTip(enc.description);
         if (transcoderWhenDifferent) {
             transcoderWhenDifferent->setVisible(true);
         }
+        if (transcoderWhenSourceIsLosssless) {
+            transcoderWhenSourceIsLosssless->setVisible(true);
+        }
         if (enc.values.count()) {
             transcoderValue->setValues(enc);
             transcoderValue->setVisible(true);
@@ -389,6 +399,7 @@ DeviceOptions DevicePropertiesWidget::settings()
     opts.transcoderCodec=QString();
     opts.transcoderValue=0;
     opts.transcoderWhenDifferent=false;
+    opts.transcoderWhenSourceIsLosssless=false;
     opts.coverName=cover();
     opts.coverMaxSize=(!coverMaxSize || 0==coverMaxSize->currentIndex()) ? 0 : ((coverMaxSize->count()-coverMaxSize->currentIndex())*100);
     opts.volumeId=defaultVolume && defaultVolume->isVisible() ? defaultVolume->itemData(defaultVolume->currentIndex()).toString() : QString();
@@ -399,6 +410,7 @@ DeviceOptions DevicePropertiesWidget::settings()
             Encoders::Encoder enc=Encoders::getEncoder(opts.transcoderCodec);
 
             opts.transcoderWhenDifferent=transcoderWhenDifferent ? transcoderWhenDifferent->isChecked() : false;
+            opts.transcoderWhenSourceIsLosssless=transcoderWhenSourceIsLosssless ? transcoderWhenSourceIsLosssless->isChecked() : false;
             if (!enc.isNull() && transcoderValue->value()<enc.values.count()) {
                 opts.transcoderValue=enc.values.at(transcoderValue->value()).value;
             }
