@@ -42,6 +42,7 @@
 #endif
 #include <QSystemTrayIcon>
 #include <QSysInfo>
+#include <QStyleFactory>
 
 #define REMOVE(w) \
     w->setVisible(false); \
@@ -106,26 +107,21 @@ static const char * constSep=",";
 
 InterfaceSettings::InterfaceSettings(QWidget *p)
     : QWidget(p)
-    , loadedLangs(false)
+    , loaded(false)
 {
+    bool mprisSettings=false;
+    bool enableTrayItem=Utils::useSystemTray();
     #ifdef Q_OS_MAC
     // OSX always displays an entry in the taskbar - and the tray seems to confuse things.
-    bool enableTrayItem=false;
     bool enableNotifications=QSysInfo::MacintoshVersion >= QSysInfo::MV_10_8;
     #else
     #ifdef QT_QTDBUS_FOUND
     // We have dbus, check that org.freedesktop.Notifications exists
     bool enableNotifications=QDBusConnection::sessionBus().interface()->isServiceRegistered("org.freedesktop.Notifications");
+    mprisSettings=true;
     #else // QT_QTDBUS_FOUND
     bool enableNotifications=true;
     #endif // QT_QTDBUS_FOUND
-    bool enableTrayItem=true;
-    if (!QSystemTrayIcon::isSystemTrayAvailable()) {
-        enableTrayItem=false;
-        #ifndef QT_QTDBUS_FOUND
-        enableNotifications=false;
-        #endif
-    }
     #endif // Q_MAC_OS
 
     setupUi(this);
@@ -183,14 +179,14 @@ InterfaceSettings::InterfaceSettings(QWidget *p)
         REMOVE(startupState)
     }
 
-    if (!enableNotifications && !enableTrayItem) {
+    if (!enableNotifications && !enableTrayItem && !mprisSettings) {
         tabWidget->removeTab(3);
-    } else if (!enableTrayItem && enableNotifications) {
+    } else if (!enableTrayItem && enableNotifications && !mprisSettings) {
         tabWidget->setTabText(3, tr("Notifications"));
     }
-    #if !defined QT_QTDBUS_FOUND
-    REMOVE(enableMpris)
-    #endif
+    if (!mprisSettings) {
+        REMOVE(enableMpris)
+    }
     #if defined Q_OS_WIN || defined Q_OS_MAC || !defined QT_QTDBUS_FOUND
     if (systemTrayPopup && systemTrayCheckBox) {
         connect(systemTrayCheckBox, SIGNAL(toggled(bool)), SLOT(systemTrayCheckBoxToggled()));
@@ -324,10 +320,12 @@ void InterfaceSettings::save()
         Settings::self()->saveStartupState(Settings::SS_Previous);
     }
     Settings::self()->saveFetchCovers(fetchCovers->isChecked());
-    if (loadedLangs && lang) {
+    if (loaded && lang) {
         Settings::self()->saveLang(lang->itemData(lang->currentIndex()).toString());
     }
-
+    if (loaded && styleOption) {
+        Settings::self()->saveStyle(0==styleOption->currentIndex() ? QString() : styleOption->currentText());
+    }
     QStringList hiddenPages;
     for (int i=0; i<views->count(); ++i) {
         QListWidgetItem *v=views->item(i);
@@ -368,8 +366,8 @@ static QSet<QString> translationCodes(const QString &dir)
 
 void InterfaceSettings::showEvent(QShowEvent *e)
 {
-    if (!loadedLangs) {
-        loadedLangs=true;
+    if (!loaded) {
+        loaded=true;
 
         QMap<QString, QString> langMap;
         QSet<QString> transCodes;
@@ -410,6 +408,27 @@ void InterfaceSettings::showEvent(QShowEvent *e)
         } else {
             connect(lang, SIGNAL(currentIndexChanged(int)), SLOT(langChanged()));
         }
+
+        styleOption->addItem(tr("System default"));
+        styleOption->addItems(QStyleFactory::keys());
+
+        if (styleOption->count()<3) {
+            REMOVE(styleOption)
+            REMOVE(styleLabel)
+            REMOVE(styleNoteLabel)
+        } else {
+            QString selected = Settings::self()->style();
+            styleOption->setCurrentIndex(0);
+            if (!selected.isEmpty()) {
+                for (int i=1; i<styleOption->count(); ++i) {
+                    if (styleOption->itemText(i) == selected) {
+                        styleOption->setCurrentIndex(i);
+                        break;
+                    }
+                }
+            }
+            connect(styleOption, SIGNAL(currentIndexChanged(int)), SLOT(styleChanged()));
+        }
     }
     QWidget::showEvent(e);
 }
@@ -462,6 +481,12 @@ void InterfaceSettings::langChanged()
     langNoteLabel->setOn(lang->itemData(lang->currentIndex()).toString()!=Settings::self()->lang());
 }
 
+void InterfaceSettings::styleChanged()
+{
+    QString st = 0==styleOption->currentIndex() ? QString() : styleOption->currentText();
+    styleNoteLabel->setOn(st!=Settings::self()->style());
+}
+
 void InterfaceSettings::viewItemChanged(QListWidgetItem *changedItem)
 {
     // If this is the playqueue that has been toggled, then control auto-hide
