@@ -44,7 +44,7 @@
 #include "context/wikipediaengine.h"
 #include "context/lastfmengine.h"
 #include "context/metaengine.h"
-#include "dynamic/dynamic.h"
+#include "playlists/dynamicplaylists.h"
 #ifdef ENABLE_DEVICES_SUPPORT
 #include "models/devicesmodel.h"
 #endif
@@ -65,6 +65,8 @@
 #include <QMutexLocker>
 #include <QTextStream>
 #include <QDateTime>
+#include <QByteArray>
+
 static QMutex msgMutex;
 static bool firstMsg=true;
 static void cantataQtMsgHandler(QtMsgType, const QMessageLogContext &, const QString &msg)
@@ -181,7 +183,7 @@ static void installDebugMessageHandler()
             ContextWidget::enableDebug();
         }
         if (dbg&Dbg_Dynamic) {
-            Dynamic::enableDebug();
+            DynamicPlaylists::enableDebug();
         }
         if (dbg&Dbg_StreamFetching) {
             StreamFetcher::enableDebug();
@@ -201,11 +203,11 @@ static void installDebugMessageHandler()
         if (dbg&Dbg_Threads) {
             ThreadCleaner::enableDebug();
         }
-	#ifdef ENABLE_TAGLIB
+        #ifdef ENABLE_TAGLIB
         if (dbg&Dbg_Tags) {
             TagHelperIface::enableDebug();
         }
-	#endif
+        #endif
         if (dbg&Dbg_Scrobbling) {
             Scrobbler::enableDebug();
         }
@@ -238,7 +240,7 @@ int main(int argc, char *argv[])
     QCoreApplication::setOrganizationName(ORGANIZATION_NAME);
 
     QGuiApplication::setAttribute(Qt::AA_UseHighDpiPixmaps);
-    #if QT_VERSION >= 0x050600
+    #if QT_VERSION >= 0x050600 && defined Q_OS_WIN
     QGuiApplication::setAttribute(Qt::AA_EnableHighDpiScaling);
     #endif
 
