@@ -632,11 +632,6 @@ QString Settings::lang()
     return cfg.get("lang", QString());
 }
 
-bool Settings::showMenubar()
-{
-    return cfg.get("showMenubar", false);
-}
-
 bool Settings::showCoverWidget()
 {
     return cfg.get("showCoverWidget", true);
@@ -1084,11 +1079,6 @@ void Settings::saveLang(const QString &v)
     cfg.set("lang", v);
 }
 
-void Settings::saveShowMenubar(bool v)
-{
-    cfg.set("showMenubar", v);
-}
-
 void Settings::saveShowCoverWidget(bool v)
 {
     cfg.set("showCoverWidget", v);
@@ -1126,6 +1116,11 @@ void Settings::saveReplayGain(const QString &conn, const QString &v)
     grp.set("replayGain", v);
 }
 
+void Settings::saveStyle(const QString &v)
+{
+    cfg.set("style", v);
+}
+
 void Settings::save()
 {
     if (AP_NotConfigured!=state) {
