@@ -40,6 +40,8 @@
 #include <QDebug>
 #define DBUG if (HttpServer::debugEnabled()) qWarning() << "HttpSocket" << __FUNCTION__
 
+static const quint64 constMaxBuffer = 32768;
+
 static QString detectMimeType(const QString &file)
 {
     QString suffix = QFileInfo(file).suffix().toLower();
@@ -227,9 +229,28 @@ void HttpSocket::handleNewConnection()
 {
     DBUG;
     while (hasPendingConnections()) {
-        QTcpSocket *s = nextPendingConnection();
-        connect(s, SIGNAL(readyRead()), this, SLOT(readClient()));
-        connect(s, SIGNAL(disconnected()), this, SLOT(discardClient()));
+        QTcpSocket *socket = nextPendingConnection();
+
+        // prevent clients from sending too much data
+        socket->setReadBufferSize(constMaxBuffer);
+
+        static const QLatin1String constIpV6Prefix("::ffff:");
+
+        QString peer=socket->peerAddress().toString();
+        QString ifaceAddress=serverAddress().toString();
+        const bool hostOk=peer==ifaceAddress || peer==mpdAddr || peer==(constIpV6Prefix+mpdAddr) ||
+                          peer==QLatin1String("127.0.0.1") || peer==(constIpV6Prefix+QLatin1String("127.0.0.1"));
+
+        DBUG << "peer:" << peer << "mpd:" << mpdAddr << "iface:" << ifaceAddress << "ok:" << hostOk;
+        if (!hostOk) {
+            sendErrorResponse(socket, 400);
+            socket->close();
+            DBUG << "Not from valid host";
+            return;
+        }
+
+        connect(socket, SIGNAL(readyRead()), this, SLOT(readClient()));
+        connect(socket, SIGNAL(disconnected()), this, SLOT(discardClient()));
     }
 }
 
@@ -240,6 +261,15 @@ void HttpSocket::readClient()
     }
 
     QTcpSocket *socket = static_cast<QTcpSocket *>(sender());
+
+    if (socket->bytesAvailable() >= constMaxBuffer) {
+        // Request too large, reject
+        sendErrorResponse(socket, 400);
+        socket->close();
+        DBUG << "Request too large";
+        return;
+    }
+
     if (socket->canReadLine()) {
         QList<QByteArray> tokens = split(socket->readLine()); // QRegExp("[ \r\n][ \r\n]*"));
         if (tokens.length()>=2 && "GET"==tokens[0]) {
@@ -253,21 +283,6 @@ void HttpSocket::readClient()
                 return;
             }
 
-            static const QLatin1String constIpV6Prefix("::ffff:");
-
-            QString peer=socket->peerAddress().toString();
-            QString ifaceAddress=serverAddress().toString();
-            bool hostOk=peer==ifaceAddress || peer==mpdAddr || peer==(constIpV6Prefix+mpdAddr) ||
-                        peer==QLatin1String("127.0.0.1") || peer==(constIpV6Prefix+QLatin1String("127.0.0.1"));
-
-            DBUG << "peer:" << peer << "mpd:" << mpdAddr << "iface:" << ifaceAddress << "ok:" << hostOk;
-            if (!hostOk) {
-                sendErrorResponse(socket, 400);
-                socket->close();
-                DBUG << "Not from valid host";
-                return;
-            }
-
             QUrl url(QUrl::fromEncoded(tokens[1]));
             QUrlQuery q(url);
             bool ok=false;
@@ -399,6 +414,12 @@ void HttpSocket::readClient()
             if (QTcpSocket::UnconnectedState==socket->state()) {
                 delete socket;
             }
+        } else {
+            // Bad Request
+            sendErrorResponse(socket, 400);
+            socket->close();
+            DBUG << "Bad Request";
+            return;
         }
     }
 }
