@@ -1,7 +1,7 @@
 /*
  * Cantata
  *
- * Copyright (c) 2011-2016 Craig Drummond <craig.p.drummond@gmail.com>
+ * Copyright (c) 2011-2017 Craig Drummond <craig.p.drummond@gmail.com>
  *
  */
 /*
@@ -31,7 +31,6 @@
 #include "musiclibrarymodel.h"
 #include "mpd-interface/mpdparseutils.h"
 #include "mpd-interface/mpdconnection.h"
-#include "support/localize.h"
 #include "qtiocompressor/qtiocompressor.h"
 #include <QXmlStreamReader>
 #include <QXmlStreamWriter>
@@ -134,7 +133,9 @@ void MusicLibraryItemRoot::getDetails(QSet<QString> &artists, QSet<QString> &alb
             albumArtists.insert(s.albumArtist());
             composers.insert(s.composer());
             albums.insert(s.album);
-            genres+=s.genres().toSet();
+            for (int i=0; i<Song::constNumGenres && !s.genres[i].isEmpty(); ++i) {
+                genres+=s.genres[i];
+            }
         } else if (MusicLibraryItem::Type_Artist==child->itemType()) {
             foreach (const MusicLibraryItem *album, static_cast<const MusicLibraryItemContainer *>(child)->childItems()) {
                 foreach (const MusicLibraryItem *song, static_cast<const MusicLibraryItemContainer *>(album)->childItems()) {
@@ -143,7 +144,9 @@ void MusicLibraryItemRoot::getDetails(QSet<QString> &artists, QSet<QString> &alb
                     albumArtists.insert(s.albumArtist());
                     composers.insert(s.composer());
                     albums.insert(s.album);
-                    genres+=s.genres().toSet();
+                    for (int i=0; i<Song::constNumGenres && !s.genres[i].isEmpty(); ++i) {
+                        genres+=s.genres[i];
+                    }
                 }
             }
         }
@@ -300,9 +303,12 @@ void MusicLibraryItemRoot::toXML(QXmlStreamWriter &writer, MusicLibraryProgressM
                 if (song.hasAlbumArtistSort()) {
                     writer.writeAttribute(constAlbumArtistSortAttribute, song.albumArtistSort());
                 }
-                QString trackGenre=track->multipleGenres() ? Song::combineGenres(track->allGenres()) : track->genre();
+                QString trackGenre=track->song().genres[0];
+                for (int i=1; i<Song::constNumGenres && !track->song().genres[i].isEmpty(); ++i) {
+                    trackGenre+=","+track->song().genres[i];
+                }
                 if (!trackGenre.isEmpty() && trackGenre!=Song::unknown()) {
-                    writer.writeAttribute(constGenreAttribute, song.genre);
+                    writer.writeAttribute(constGenreAttribute, trackGenre);
                 }
                 if (Song::Playlist==song.type) {
                     writer.writeAttribute(constPlaylistAttribute, constTrueValue);
@@ -379,7 +385,7 @@ bool MusicLibraryItemRoot::fromXML(QXmlStreamReader &reader, const QString &base
 
         if (reader.error()) {
             if (em) {
-                em->loadError(i18n("Parse error loading cache file, please check your songs tags."));
+                em->loadError(QObject::tr("Parse error loading cache file, please check your songs tags."));
             }
         } else if (reader.isStartElement()) {
             QString element = reader.name().toString();
@@ -437,9 +443,9 @@ bool MusicLibraryItemRoot::fromXML(QXmlStreamReader &reader, const QString &base
                     song.setAlbumArtistSort(attributes.value(constAlbumArtistSortAttribute).toString());
                 }
                 if (attributes.hasAttribute(constGenreAttribute)) {
-                    QStringList genres=attributes.value(constGenreAttribute).toString().split(Song::constGenreSep, QString::SkipEmptyParts);
-                    foreach (const QString &genre, genres) {
-                        song.addGenre(genre);
+                    QStringList genres=attributes.value(constGenreAttribute).toString().split(",", QString::SkipEmptyParts);
+                    for (int i=0; i<Song::constNumGenres && i<genres.count(); ++i) {
+                        song.addGenre(genres[i]);
                     }
                 }
                 if (attributes.hasAttribute(constPlaylistAttribute) && constTrueValue==attributes.value(constPlaylistAttribute).toString()) {
