@@ -224,7 +224,8 @@ void MPDConnectionDetails::setDirReadable()
 }
 
 MPDConnection::MPDConnection()
-    : thread(0)
+    : isInitialConnect(true)
+    , thread(0)
     , ver(0)
     , canUseStickers(false)
     , sock(this)
@@ -261,6 +262,7 @@ MPDConnection::MPDConnection()
     qRegisterMetaType<MPDStatsValues>("MPDStatsValues");
     qRegisterMetaType<MPDStatusValues>("MPDStatusValues");
     qRegisterMetaType<MPDConnectionDetails>("MPDConnectionDetails");
+    qRegisterMetaType<QMap<qint32, quint8> >("QMap<qint32, quint8>");
     qRegisterMetaType<Stream>("Stream");
     qRegisterMetaType<QList<Stream> >("QList<Stream>");
     #if (defined Q_OS_LINUX && defined QT_QTDBUS_FOUND) || (defined Q_OS_MAC && defined IOKIT_FOUND)
@@ -484,23 +486,24 @@ void MPDConnection::reconnect()
     if (reconnectTimer && reconnectTimer->isActive()) {
         return;
     }
-    if (0==reconnectStart) {
-        if (isConnected()) {
-            disconnectFromMPD();
-        } else {
-            return;
-        }
+    qWarning() << reconnectStart;
+    if (0==reconnectStart && isConnected()) {
+        disconnectFromMPD();
     }
 
     if (isConnected()) { // Perhaps the user pressed a button which caused the reconnect???
         reconnectStart=0;
         return;
     }
-
+qWarning() << "TRY TO CONNECT";
     time_t now=time(NULL);
     ConnectionReturn status=connectToMPD();
     switch (status) {
-    case Success:
+    case Success:        
+        // Issue #1041 - MPD does not seem to persist user/client made replaygain changes, so use the values read from Cantata's config.
+        if (replaygainSupported() && !details.replayGain.isEmpty()) {
+            sendCommand("replay_gain_mode "+details.replayGain.toLatin1());
+        }
         getStatus();
         getStats();
         getUrlHandlers();
@@ -509,6 +512,7 @@ void MPDConnection::reconnect()
         playListInfo();
         outputs();
         reconnectStart=0;
+        determineIfaceIp();
         emit stateChanged(true);
         break;
     case Failed:
@@ -598,11 +602,17 @@ void MPDConnection::setDetails(const MPDConnectionDetails &d)
             getUrlHandlers();
             getTagTypes();
             getStickerSupport();
+            playListInfo();
+            outputs();
             determineIfaceIp();
             emit stateChanged(true);
             break;
         default:
+            emit stateChanged(false);
             emit error(errorString(status), true);
+            if (isInitialConnect) {
+                reconnect();
+            }
         }
     } else if (diffName) {
          emit stateChanged(true);
@@ -615,6 +625,7 @@ void MPDConnection::setDetails(const MPDConnectionDetails &d)
     if (changedDir) {
         emit dirChanged();
     }
+    isInitialConnect = false;
 }
 
 //void MPDConnection::disconnectMpd()
@@ -632,7 +643,9 @@ MPDConnection::Response MPDConnection::sendCommand(const QByteArray &command, bo
     DBUG << (void *)(&sock) << "sendCommand:" << log(command) << emitErrors << retry;
 
     if (!isConnected()) {
-        emit error(tr("Failed to send command to %1 - not connected").arg(details.description()), true);
+        if ("stop"!=command) {
+            emit error(tr("Failed to send command to %1 - not connected").arg(details.description()), true);
+        }
         return Response(false);
     }
 
@@ -730,21 +743,26 @@ bool MPDConnection::isPlaylist(const QString &file)
            file.endsWith(QLatin1String(".xspf"), Qt::CaseInsensitive);
 }
 
-void MPDConnection::add(const QStringList &files, int action, quint8 priority)
+void MPDConnection::add(const QStringList &files, int action, quint8 priority, bool decreasePriority)
 {
-    add(files, 0, 0, action, priority);
+    add(files, 0, 0, action, priority, decreasePriority);
 }
 
-void MPDConnection::add(const QStringList &files, quint32 pos, quint32 size, int action, quint8 priority)
+void MPDConnection::add(const QStringList &files, quint32 pos, quint32 size, int action, quint8 priority, bool decreasePriority)
 {
     QList<quint8> prioList;
     if (priority>0) {
         prioList << priority;
     }
-    add(files, pos, size, action, prioList);
+    add(files, pos, size, action, prioList, decreasePriority);
 }
 
 void MPDConnection::add(const QStringList &origList, quint32 pos, quint32 size, int action, const QList<quint8> &priority)
+{
+    add(origList, pos, size, action, priority, false);
+}
+
+void MPDConnection::add(const QStringList &origList, quint32 pos, quint32 size, int action, QList<quint8> priority, bool decreasePriority)
 {
     quint32 playPos=0;
     if (0==pos && 0==size && (AddAfterCurrent==action || AppendAndPlay==action || AddAndPlay==action)) {
@@ -793,6 +811,18 @@ void MPDConnection::add(const QStringList &origList, quint32 pos, quint32 size,
     int curPos = pos;
     //    bool addedFile=false;
     bool havePlaylist=false;
+
+    if (1==priority.count() && decreasePriority) {
+        quint8 prio=priority.at(0);
+        priority.clear();
+        for (int i=0; i<files.count(); ++i) {
+            priority.append(prio);
+            if (prio>1) {
+                prio--;
+            }
+        }
+    }
+
     bool usePrio=!priority.isEmpty() && canUsePriority() && (1==priority.count() || priority.count()==files.count());
     quint8 singlePrio=usePrio && 1==priority.count() ? priority.at(0) : 0;
     QStringList cStreamFiles;
@@ -1235,6 +1265,9 @@ void MPDConnection::seek()
     Response response=sendCommand("status");
     if (response.ok) {
         MPDStatusValues sv=MPDParseUtils::parseStatus(response.data);
+        if (-1==sv.songId) {
+            return;
+        }
         if (offset>0) {
             if (sv.timeElapsed+offset<sv.timeTotal) {
                 setSeek(sv.song, sv.timeElapsed+offset);
@@ -1744,18 +1777,23 @@ void MPDConnection::removeFromPlaylist(const QString &name, const QList<quint32>
 //     playlistInfo(name);
 }
 
-void MPDConnection::setPriority(const QList<qint32> &ids, quint8 priority)
+void MPDConnection::setPriority(const QList<qint32> &ids, quint8 priority, bool decreasePriority)
 {
     if (canUsePriority()) {
+        QMap<qint32, quint8> tracks;
         QByteArray send = "command_list_begin\n";
 
         foreach (quint32 id, ids) {
+            tracks.insert(id, priority);
             send += "prioid "+quote(priority)+" "+quote(id)+'\n';
+            if (decreasePriority && priority>0) {
+                priority--;
+            }
         }
 
         send += "command_list_end";
         if (sendCommand(send).ok) {
-            emit prioritySet(ids, priority);
+            emit prioritySet(tracks);
         }
     }
 }
@@ -1792,6 +1830,54 @@ void MPDConnection::search(const QString &field, const QString &value, int id)
     emit searchResponse(id, songs);
 }
 
+void MPDConnection::search(const QByteArray &query, const QString &id)
+{
+    QList<Song> songs;
+    if (query.isEmpty()) {
+        Response response=sendCommand("list albumartist", false, false);
+        if (response.ok) {
+            QList<QByteArray> lines = response.data.split('\n');
+            foreach (const QByteArray &line, lines) {
+                if (line.startsWith("AlbumArtist: ")) {
+                    Response resp = sendCommand("find albumartist " + encodeName(QString::fromUtf8(line.mid(13))) , false, false);
+                    if (resp.ok) {
+                        songs += MPDParseUtils::parseSongs(resp.data, MPDParseUtils::Loc_Search);
+                    }
+                }
+            }
+        }
+    } else if (query.startsWith("RATING:")) {
+        QList<QByteArray> parts = query.split(':');
+        if (3==parts.length()) {
+            Response response=sendCommand("sticker find song \"\" rating", false, false);
+            if (response.ok) {
+                int min = parts.at(1).toInt();
+                int max = parts.at(2).toInt();
+                QList<MPDParseUtils::Sticker> stickers=MPDParseUtils::parseStickers(response.data, constRatingSticker);
+                if (!stickers.isEmpty()) {
+                    foreach (const MPDParseUtils::Sticker &sticker, stickers) {
+                        if (!sticker.file.isEmpty() && !sticker.value.isEmpty()) {
+                            int val = sticker.value.toInt();
+                            if (val>=min && val<=max) {
+                                Response resp = sendCommand("find file " + encodeName(QString::fromUtf8(sticker.file)) , false, false);
+                                if (resp.ok) {
+                                    songs.append(MPDParseUtils::parseSong(response.data, MPDParseUtils::Loc_Search));
+                                }
+                            }
+                        }
+                    }
+                }
+            }
+        }
+    } else {
+        Response response=sendCommand(query);
+        if (response.ok) {
+            songs=MPDParseUtils::parseSongs(response.data, MPDParseUtils::Loc_Search);
+        }
+    }
+    emit searchResponse(id, songs);
+}
+
 void MPDConnection::listStreams()
 {
     Response response=sendCommand("listplaylistinfo "+encodeName(constStreamsPlayListName), false);
