@@ -239,9 +239,10 @@ public Q_SLOTS:
     void setDetails(const MPDConnectionDetails &d);
 //    void disconnectMpd();
     // Current Playlist
-    void add(const QStringList &files, int action, quint8 priority);
-    void add(const QStringList &files, quint32 pos, quint32 size, int action, quint8 priority);
+    void add(const QStringList &files, int action, quint8 priority, bool decreasePriority);
+    void add(const QStringList &files, quint32 pos, quint32 size, int action, quint8 priority, bool decreasePriority);
     void add(const QStringList &files, quint32 pos, quint32 size, int action, const QList<quint8> &priority);
+    void add(const QStringList &files, quint32 pos, quint32 size, int action, QList<quint8> priority, bool decreasePriority);
     void populate(const QStringList &files, const QList<quint8> &priority);
     void addAndPlay(const QString &file);
     void currentSong();
@@ -306,9 +307,10 @@ public Q_SLOTS:
     void removeFromPlaylist(const QString &name, const QList<quint32> &positions);
     void moveInPlaylist(const QString &name, const QList<quint32> &items, quint32 row, quint32 size);
 
-    void setPriority(const QList<qint32> &ids, quint8 priority);
+    void setPriority(const QList<qint32> &ids, quint8 priority, bool decreasePriority);
 
     void search(const QString &field, const QString &value, int id);
+    void search(const QByteArray &query, const QString &id);
 
     void listStreams();
     void saveStream(const QString &url, const QString &name);
@@ -354,12 +356,13 @@ Q_SIGNALS:
     void error(const QString &err, bool showActions=false);
     void info(const QString &msg);
     void dirChanged();
-    void prioritySet(const QList<qint32> &ids, quint8 priority);
+    void prioritySet(const QMap<qint32, quint8> &tracks);
 
     void stopAfterCurrentChanged(bool afterCurrent);
     void streamUrl(const QString &url);
 
     void searchResponse(int id, const QList<Song> &songs);
+    void searchResponse(const QString &id, const QList<Song> &songs);
 
     void socketAddress(const QString &addr);
     void cantataStreams(const QStringList &files);
@@ -421,6 +424,7 @@ private:
     void determineIfaceIp();
 
 private:
+    bool isInitialConnect;
     Thread *thread;
     long ver;
     QSet<QString> handlers;
@@ -464,4 +468,5 @@ private:
     int restoreVolume;
 };
 
+
 #endif
