@@ -331,7 +331,7 @@ Song MPDParseUtils::parseSong(const QList<QByteArray> &lines, Location location)
             song.origYear=v<0 ? 0 : v;
         } else if (line.startsWith(constGenreKey)) {
             song.addGenre(QString::fromUtf8(line.mid(constGenreKey.length())));
-        }  else if (line.startsWith(constNameKey)) {
+        } else if (line.startsWith(constNameKey)) {
             song.setName(QString::fromUtf8(line.mid(constNameKey.length())));
         } else if (line.startsWith(constPlaylistKey)) {
             song.file = QString::fromUtf8(line.mid(constPlaylistKey.length()));
@@ -339,8 +339,9 @@ Song MPDParseUtils::parseSong(const QList<QByteArray> &lines, Location location)
             song.type=Song::Playlist;
         }  else if (line.startsWith(constAlbumId)) {
             song.setMbAlbumId(line.mid(constAlbumId.length()));
-        } else if ((Loc_Search==location || Loc_Playlists==location || Loc_PlayQueue==location)  &&
-                   line.startsWith(constPerformerKey)) {
+        } else if ((Loc_Search==location || Loc_Library==location) && line.startsWith(constLastModifiedKey)) {
+            song.lastModified=QDateTime::fromString(QString::fromUtf8(line.mid(constLastModifiedKey.length())), Qt::ISODate).toTime_t();
+        } else if ((Loc_Search==location || Loc_Playlists==location || Loc_PlayQueue==location) && line.startsWith(constPerformerKey)) {
             if (song.hasPerformer()) {
                 song.setPerformer(song.performer()+QLatin1String(", ")+QString::fromUtf8(line.mid(constPerformerKey.length())));
             } else {
@@ -359,8 +360,6 @@ Song MPDParseUtils::parseSong(const QList<QByteArray> &lines, Location location)
                 song.setArtistSort(QString::fromUtf8(line.mid(constArtistSortKey.length())));
             } else if (line.startsWith(constAlbumArtistSortKey)) {
                 song.setAlbumArtistSort(QString::fromUtf8(line.mid(constAlbumArtistSortKey.length())));
-            } else if (line.startsWith(constLastModifiedKey)) {
-                song.lastModified=QDateTime::fromString(QString::fromUtf8(line.mid(constLastModifiedKey.length())), Qt::ISODate).toTime_t();
             }
         }
     }
@@ -788,6 +787,29 @@ QByteArray MPDParseUtils::parseSticker(const QByteArray &data, const QByteArray
     return QByteArray();
 }
 
+QList<MPDParseUtils::Sticker> MPDParseUtils::parseStickers(const QByteArray &data, const QByteArray &sticker)
+{
+    QList<Sticker> stickers;
+    QList<QByteArray> lines = data.split('\n');
+    Sticker s;
+    QByteArray key=constSticker+sticker+'=';
+
+    foreach (const QByteArray &line, lines) {
+        if (constOkValue==line) {
+            break;
+        }
+
+        if (line.startsWith(constFileKey)) {
+            s.file=line.mid(constFileKey.length());
+        } else if (line.startsWith(key)) {
+            s.value=line.mid(key.length());
+            stickers.append(s);
+        }
+    }
+
+    return stickers;
+}
+
 QString MPDParseUtils::addStreamName(const QString &url, const QString &name)
 {
     return name.isEmpty()
