@@ -1,7 +1,7 @@
 /*
  * Cantata
  *
- * Copyright (c) 2011-2016 Craig Drummond <craig.p.drummond@gmail.com>
+ * Copyright (c) 2011-2017 Craig Drummond <craig.p.drummond@gmail.com>
  *
  * ----
  *
@@ -630,14 +630,17 @@ namespace FontAwesome {
     yen                     =           0xf157,
     youtube                 =           0xf167,
     youtubeplay             =           0xf16a,
-    youtubesquare           =           0xf166
+    youtubesquare           =           0xf166,
+
+    podcast                 =           0xf2ce
   };
 }
 
 namespace MonoIcon
 {
-    QIcon icon(const QString &fileName, const QColor &col, const QColor &sel);
-    QIcon icon(const FontAwesome::icon icon, const QColor &col, const QColor &sel);
+    extern const QColor constRed;
+    extern QIcon icon(const QString &fileName, const QColor &col, const QColor &sel=QColor(QColor::Invalid));
+    extern QIcon icon(const FontAwesome::icon icon, const QColor &col, const QColor &sel=QColor(QColor::Invalid));
 };
 
 #endif // MonoIcon_H
