@@ -35,6 +35,7 @@
 #include <QDesktopWidget>
 #include <QEventLoop>
 #include <QStandardPaths>
+#include <QSet>
 #ifndef _MSC_VER 
 #include <unistd.h>
 #include <utime.h>
@@ -48,6 +49,10 @@
 #include <pwd.h>
 #endif
 #include <sys/types.h>
+#if QT_QTDBUS_FOUND && !defined Q_OS_MAC && !defined Q_OS_WIN
+#include <QDBusConnection>
+#include <QDBusConnectionInterface>
+#endif
 
 const QLatin1Char Utils::constDirSep('/');
 const QLatin1String Utils::constDirSepStr("/");
@@ -891,13 +896,13 @@ Utils::Desktop Utils::currentDe()
     static int de=-1;
     if (-1==de) {
         de=Other;
-        QByteArray desktop=qgetenv("XDG_CURRENT_DESKTOP").toLower();
-        if ("unity"==desktop) {
+        QSet<QByteArray> desktop=qgetenv("XDG_CURRENT_DESKTOP").toLower().split(':').toSet();
+        if (desktop.contains("unity")) {
             de=Unity;
-        } else if ("kde"==desktop) {
+        } else if (desktop.contains("kde")) {
             de=KDE;
-        } else if ("gnome"==desktop || "pantheon"==desktop) {
-            de=Gnome;
+        } else if (desktop.contains("gnome") || desktop.contains("pantheon")) {
+            de=desktop.contains("ubuntu") ? Ubuntu_Gnome : Gnome;
         } else {
             QByteArray kde=qgetenv("KDE_FULL_SESSION");
             if ("true"==kde) {
@@ -910,6 +915,19 @@ Utils::Desktop Utils::currentDe()
     return Other;
 }
 
+bool Utils::useSystemTray()
+{
+    #if defined Q_OS_MAC
+    return false;
+    #elif defined Q_OS_WIN
+    return true;
+    #elif QT_QTDBUS_FOUND
+    return QDBusConnection::sessionBus().interface()->isServiceRegistered("org.kde.StatusNotifierWatcher");
+    #else
+    return false;
+    #endif
+}
+
 QPainterPath Utils::buildPath(const QRectF &r, double radius)
 {
     QPainterPath path;
