@@ -114,10 +114,12 @@ namespace Utils
     enum Desktop {
         KDE,
         Gnome,
+        Ubuntu_Gnome,
         Unity,
         Other
     };
     extern Desktop currentDe();
+    extern bool useSystemTray();
     extern QPainterPath buildPath(const QRectF &r, double radius);
     extern QColor clampColor(const QColor &col);
     extern QColor monoIconColor();
