@@ -1,7 +1,7 @@
 /*
  * Cantata
  *
- * Copyright (c) 2011-2016 Craig Drummond <craig.p.drummond@gmail.com>
+ * Copyright (c) 2011-2017 Craig Drummond <craig.p.drummond@gmail.com>
  *
  * ----
  *
@@ -86,16 +86,6 @@
 #include <taglib-extras/realmediafiletyperesolver.h>
 #endif
 
-#ifdef ENABLE_EXTERNAL_TAGS
-// Mutex is locked in client, and server (that accesses this class) is single threaded
-#define LOCK_MUTEX
-#else
-#include <QMutex>
-#include <QMutexLocker>
-static QMutex mutex;
-#define LOCK_MUTEX QMutexLocker locker(&mutex);
-#endif
-
 namespace Tags
 {
 
@@ -328,7 +318,6 @@ static void readID3v2Tags(TagLib::ID3v2::Tag *tag, Song *song, ReplayGain *rg, Q
         if (!tcon.isEmpty()) {
             TagLib::ID3v2::FrameList::ConstIterator it = tcon.begin();
             TagLib::ID3v2::FrameList::ConstIterator end = tcon.end();
-            QSet<QString> genres;
 
             for (; it!=end; ++it) {
                 TagLib::ID3v2::TextIdentificationFrame *f = static_cast<TagLib::ID3v2::TextIdentificationFrame *>(*it);
@@ -349,13 +338,7 @@ static void readID3v2Tags(TagLib::ID3v2::Tag *tag, Song *song, ReplayGain *rg, Q
                     } else {
                         genre = tString2QString(*fIt);
                     }
-                    if (!genres.contains(genre)) {
-                        genres.insert(genre);
-                        if (!song->genre.isEmpty()) {
-                            song->genre+=Song::constGenreSep;
-                        }
-                        song->genre+=genre;
-                    }
+                    song->addGenre(genre);
                 }
             }
         }
@@ -504,20 +487,18 @@ static bool writeID3v2Tags(TagLib::ID3v2::Tag *tag, const Song &from, const Song
         if (from.disc!=to.disc&& updateID3v2Tag(tag, "TPOS", 0==to.disc ? QString() : QString::number(to.disc))) {
             changed=true;
         }
-        DBUG << "genres" << from.genre << to.genre;
-        if (from.genre!=to.genre) {
+        DBUG << "genres" << from.genres << to.genres;
+        if (0!=from.compareGenres(to)) {
             tag->removeFrames("TCON");
-            QStringList genres=to.genres();
-            DBUG << "num genres:" << genres.count();
-            if (genres.count()<2) {
-                DBUG << "set genre" << (genres.isEmpty() ? QString() : genres.first().trimmed());
-                tag->setGenre(qString2TString(genres.isEmpty() ? QString() : genres.first().trimmed()));
+            if (to.genres[1].isEmpty()) {
+                DBUG << "set genre" << (to.firstGenre().trimmed());
+                tag->setGenre(qString2TString(to.firstGenre().trimmed()));
             } else {
-                foreach (const QString &genre, genres) {
+                for(int i=0; i<Song::constNumGenres; ++i) {
                     TagLib::ID3v2::TextIdentificationFrame *frame = new TagLib::ID3v2::TextIdentificationFrame("TCON");
                     tag->addFrame(frame);
-                    DBUG << "add genre" << genre.trimmed();
-                    frame->setText(qString2TString(genre.trimmed()));
+                    DBUG << "add genre" << to.genres[i].trimmed();
+                    frame->setText(qString2TString(to.genres[i].trimmed()));
                 }
             }
             changed=true;
@@ -659,14 +640,13 @@ static bool writeAPETags(TagLib::APE::Tag *tag, const Song &from, const Song &to
         if (from.disc!=to.disc && updateAPETag(tag, "Disc", 0==to.disc ? QString() : QString::number(to.disc))) {
             changed=true;
         }
-        if (from.genre!=to.genre) {
+        if (0!=from.compareGenres(to)) {
             tag->removeItem("GENRE");
-            QStringList genres=to.genres();
-            if (genres.count()<2) {
-                tag->setGenre(qString2TString(genres.isEmpty() ? QString() : genres.first().trimmed()));
+            if (to.genres[1].isEmpty()) {
+                tag->setGenre(qString2TString(to.firstGenre().trimmed()));
             } else {
-                foreach (const QString &genre, genres) {
-                    tag->addValue("GENRE", qString2TString(genre.trimmed()), false);
+                for(int i=0; i<Song::constNumGenres; ++i) {
+                    tag->addValue("GENRE", qString2TString(to.genres[i].trimmed()), false);
                 }
             }
             changed=true;
@@ -831,14 +811,13 @@ static bool writeVorbisCommentTags(TagLib::Ogg::XiphComment *tag, const Song &fr
         if (from.disc!=to.disc && updateVorbisCommentTag(tag, "DISCNUMBER", 0==to.disc ? QString() : QString::number(to.disc))) {
             changed=true;
         }
-        if (from.genre!=to.genre) {
+        if (0!=from.compareGenres(to)) {
             tag->removeField("GENRE");
-            QStringList genres=to.genres();
-            if (genres.count()<2) {
-                tag->setGenre(qString2TString(genres.isEmpty() ? QString() : genres.first().trimmed()));
+            if (to.genres[1].isEmpty()) {
+                tag->setGenre(qString2TString(to.firstGenre().trimmed()));
             } else {
-                foreach (const QString &genre, genres) {
-                    tag->addField("GENRE", qString2TString(genre.trimmed()), false);
+                for(int i=0; i<Song::constNumGenres; ++i) {
+                    tag->addField("GENRE", qString2TString(to.genres[i].trimmed()), false);
                 }
             }
             changed=true;
@@ -860,11 +839,7 @@ static bool writeVorbisCommentTags(TagLib::Ogg::XiphComment *tag, const Song &fr
     }
 
     if (!img.isEmpty()) {
-        #if QT_VERSION < 0x050000
-        tag->addField("COVERART", qString2TString(QString::fromAscii(img.toBase64())));
-        #else
         tag->addField("COVERART", qString2TString(QString::fromLatin1(img.toBase64())));
-        #endif
         changed=true;
     }
 
@@ -881,7 +856,7 @@ static bool writeVorbisCommentTags(TagLib::Ogg::XiphComment *tag, const Song &fr
 }
 
 #ifdef TAGLIB_MP4_FOUND
-static void readMP4Tags(TagLib::MP4::Tag *tag, Song *song, ReplayGain *rg, QImage *img, int *rating)
+static void readMP4Tags(TagLib::MP4::Tag *tag, Song *song, ReplayGain *rg, QImage *img, QString *lyrics, int *rating)
 {
     TagLib::MP4::ItemListMap &map = tag->itemListMap();
 
@@ -928,6 +903,11 @@ static void readMP4Tags(TagLib::MP4::Tag *tag, Song *song, ReplayGain *rg, QImag
             }
         }
     }
+    if (lyrics) {
+        if (map.contains("\251lyr") && !map["\251lyr"].toStringList().isEmpty()) {
+            *lyrics=tString2QString(map["\251lyr"].toStringList().front());
+        }
+    }
     if (rating) {
         if (map.contains("----:com.apple.iTunes:FMPS_Rating")) {
             *rating=convertToCantataRating(parseDoubleString(map["----:com.apple.iTunes:FMPS_Rating"].toStringList().front()));
@@ -965,14 +945,13 @@ static bool writeMP4Tags(TagLib::MP4::Tag *tag, const Song &from, const Song &to
         if (from.disc!=to.disc && updateMP4Tag(tag, "disk", 0==to.disc ? QString() : QString::number(to.disc))) {
             changed=true;
         }
-        if (from.genre!=to.genre) {
-            QStringList genres=to.genres();
-            if (genres.count()<2) {
-                tag->setGenre(qString2TString(genres.isEmpty() ? QString() : genres.first().trimmed()));
+        if (0!=from.compareGenres(to)) {
+            if (to.genres[1].isEmpty()) {
+                tag->setGenre(qString2TString(to.firstGenre().trimmed()));
             } else {
                 TagLib::StringList tagGenres;
-                foreach (const QString &genre, genres) {
-                    tagGenres.append(qString2TString(genre.trimmed()));
+                for(int i=0; i<Song::constNumGenres; ++i) {
+                    tagGenres.append(qString2TString(to.genres[i].trimmed()));
                 }
                 tag->itemListMap()["\251gen"]=tagGenres;
             }
@@ -1007,7 +986,7 @@ static bool writeMP4Tags(TagLib::MP4::Tag *tag, const Song &from, const Song &to
 
     if (rating>-1) {
         int old=-1;
-        readMP4Tags(tag, 0, 0, 0, &old);
+        readMP4Tags(tag, 0, 0, 0, 0, &old);
         if (old!=rating) {
             TagLib::MP4::ItemListMap &map = tag->itemListMap();
             map["----:com.apple.iTunes:FMPS_Rating"] = TagLib::MP4::Item(TagLib::StringList(convertFromCantataRating(rating)));
@@ -1083,14 +1062,13 @@ static bool writeASFTags(TagLib::ASF::Tag *tag, const Song &from, const Song &to
         if (from.disc!=to.disc && updateASFTag(tag, "WM/PartOfSet", 0==to.disc ? QString() : QString::number(to.disc))) {
             changed=true;
         }
-        if (from.genre!=to.genre) {
+        if (0!=from.compareGenres(to)) {
             tag->removeItem("WM/Genre");
-            QStringList genres=to.genres();
-            if (genres.count()<2) {
-                tag->setGenre(qString2TString(genres.isEmpty() ? QString() : genres.first().trimmed()));
+            if (to.genres[1].isEmpty()) {
+                tag->setGenre(qString2TString(to.firstGenre().trimmed()));
             } else {
-                foreach (const QString &genre, genres) {
-                    tag->addAttribute("WM/Genre", qString2TString(genre.trimmed()));
+                for(int i=0; i<Song::constNumGenres; ++i) {
+                    tag->addAttribute("WM/Genre", qString2TString(to.genres[i].trimmed()));
                 }
             }
             changed=true;
@@ -1165,7 +1143,7 @@ static void readTags(const TagLib::FileRef fileref, Song *song, ReplayGain *rg,
     } else if (TagLib::MP4::File *file = dynamic_cast< TagLib::MP4::File * >(fileref.file())) {
         TagLib::MP4::Tag *tag = dynamic_cast< TagLib::MP4::Tag * >(file->tag());
         if (tag) {
-            readMP4Tags(tag, song, rg, img, rating);
+            readMP4Tags(tag, song, rg, img, lyrics, rating);
         }
     #endif
     } else if (TagLib::MPC::File *file = dynamic_cast< TagLib::MPC::File * >(fileref.file())) {
@@ -1202,8 +1180,8 @@ static void readTags(const TagLib::FileRef fileref, Song *song, ReplayGain *rg,
 //             readID3v1Tags(fileref, song, rg);
         }
     }
-    if (song && song->genre.isEmpty()) {
-        song->genre=tString2QString(tag->genre());
+    if (song && song->genres[0].isEmpty()) {
+        song->addGenre(tString2QString(tag->genre()));
     }
 }
 
@@ -1326,7 +1304,6 @@ static bool writeTags(const TagLib::FileRef fileref, const Song &from, const Son
 
 Song read(const QString &fileName)
 {
-    LOCK_MUTEX
     Song song;
     TagLib::FileRef fileref = getFileRef(fileName);
     if (fileref.isNull()) {
@@ -1341,7 +1318,6 @@ Song read(const QString &fileName)
 
 QImage readImage(const QString &fileName)
 {
-    LOCK_MUTEX
     QImage img;
     TagLib::FileRef fileref = getFileRef(fileName);
     if (fileref.isNull()) {
@@ -1354,7 +1330,6 @@ QImage readImage(const QString &fileName)
 
 QString readLyrics(const QString &fileName)
 {
-    LOCK_MUTEX
     QString lyrics;
     TagLib::FileRef fileref = getFileRef(fileName);
     if (fileref.isNull()) {
@@ -1367,7 +1342,6 @@ QString readLyrics(const QString &fileName)
 
 QString readComment(const QString &fileName)
 {
-    LOCK_MUTEX
     TagLib::FileRef fileref = getFileRef(fileName);
     return fileref.isNull() ? QString() : tString2QString(fileref.tag()->comment());
 }
@@ -1395,7 +1369,6 @@ static Update update(const TagLib::FileRef fileref, const Song &from, const Song
 
 Update updateArtistAndTitle(const QString &fileName, const Song &song)
 {
-    LOCK_MUTEX
     TagLib::FileRef fileref = getFileRef(fileName);
     if (fileref.isNull()) {
         return Update_Failed;
@@ -1421,14 +1394,12 @@ Update updateArtistAndTitle(const QString &fileName, const Song &song)
 
 Update update(const QString &fileName, const Song &from, const Song &to, int id3Ver, bool saveComment)
 {
-    LOCK_MUTEX
     TagLib::FileRef fileref = getFileRef(fileName);
     return fileref.isNull() ? Update_Failed : update(fileref, from, to, RgTags(), QByteArray(), id3Ver, saveComment);
 }
 
 ReplayGain readReplaygain(const QString &fileName)
 {
-    LOCK_MUTEX
     TagLib::FileRef fileref = getFileRef(fileName);
     if (fileref.isNull()) {
         return false;
@@ -1441,21 +1412,18 @@ ReplayGain readReplaygain(const QString &fileName)
 
 Update updateReplaygain(const QString &fileName, const ReplayGain &rg)
 {
-    LOCK_MUTEX
     TagLib::FileRef fileref = getFileRef(fileName);
     return fileref.isNull() ? Update_Failed : update(fileref, Song(), Song(), RgTags(rg), QByteArray());
 }
 
 Update embedImage(const QString &fileName, const QByteArray &cover)
 {
-    LOCK_MUTEX
     TagLib::FileRef fileref = getFileRef(fileName);
     return fileref.isNull() ? Update_Failed : update(fileref, Song(), Song(), RgTags(), cover);
 }
 
 QString oggMimeType(const QString &fileName)
 {
-    LOCK_MUTEX
     #ifdef Q_OS_WIN
     const wchar_t*encodedName=reinterpret_cast<const wchar_t*>(fileName.constData());
     #else
@@ -1488,7 +1456,6 @@ QString oggMimeType(const QString &fileName)
 
 int readRating(const QString &fileName)
 {
-    LOCK_MUTEX
     int rating=-1;
     TagLib::FileRef fileref = getFileRef(fileName);
     if (!fileref.isNull()) {
@@ -1499,7 +1466,6 @@ int readRating(const QString &fileName)
 
 Update updateRating(const QString &fileName, int rating)
 {
-    LOCK_MUTEX
     TagLib::FileRef fileref = getFileRef(fileName);
     return fileref.isNull() ? Update_Failed : update(fileref, Song(), Song(), RgTags(), QByteArray(), -1, false, rating);
 }
