@@ -345,6 +345,10 @@ public:
         }
 
         if (showCapacity) {
+            QColor col(Qt::white);
+            col.setAlphaF(0.25);
+            painter->fillRect(QRect(r2.x(), r2.bottom()-(textHeight+8), r2.width(), textHeight+8), col);
+
             QStyleOptionProgressBar opt;
             double capacity=index.data(Cantata::Role_Capacity).toDouble();
 
@@ -494,7 +498,7 @@ public:
             if (text.count()>1) {
                 int mainWidth=textMetrics.width(str);
                 text.takeFirst();
-                str=text.join(" - ");
+                str=text.join(QString(" – "));
                 textRect=QRect(r.x()+(mainWidth+8), r.y()+((r.height()-textHeight)/2), r.width()-(mainWidth+8), textHeight);
                 if (textRect.width()>4) {
                     str = textMetrics.elidedText(str, Qt::ElideRight, textRect.width(), QPalette::WindowText);
@@ -892,9 +896,6 @@ void ItemView::setEnabled(bool en)
 void ItemView::setLevel(int l, bool haveChildren)
 {
     currentLevel=l;
-    if (isVisible()) {
-        backAction->setEnabled(0!=currentLevel);
-    }
 
     if (Mode_IconTop==mode) {
         if (0==currentLevel || haveChildren) {
@@ -1263,12 +1264,6 @@ void ItemView::setSearchCategory(const QString &id)
     searchWidget->setCategory(id);
 }
 
-void ItemView::showEvent(QShowEvent *ev)
-{
-    QWidget::showEvent(ev);
-    backAction->setEnabled(0!=currentLevel);
-}
-
 void ItemView::showSpinner(bool v)
 {
     if (v) {
